@@ -17,7 +17,7 @@ use Path::Class;
 use File::chdir;
 use Contextual::Return;
 
-our $VERSION = version->new('0.4.0');
+our $VERSION = version->new('0.4.1');
 our $name    = 'Bazaar';
 our $exe     = 'bzr';
 our $meta    = '.bzr';
@@ -73,7 +73,7 @@ sub uptodate {
     croak "'$dir' is not a directory!" if !-e $dir;
 
     local $CWD = $dir;
-    my $ans = `$exe status $dir`;
+    my $ans = `$exe status`;
 
     return $ans ? 0 : 1;
 }
@@ -108,7 +108,7 @@ sub cat {
 sub log {
     my ($self, @args) = @_;
 
-    my $args = join ' ', @args;
+    my $args = join ' ', map {"'$_'"} @args;
 
     return
         SCALAR   { scalar `$exe log $args` }
@@ -164,7 +164,7 @@ VCS::Which::Plugin::Bazaar - The Bazaar plugin for VCS::Which
 
 =head1 VERSION
 
-This documentation refers to VCS::Which::Plugin::Bazaar version 0.4.0.
+This documentation refers to VCS::Which::Plugin::Bazaar version 0.4.1.
 
 =head1 SYNOPSIS
 
